@@ -15,7 +15,7 @@ from keypartx.basemodes.avn_base import nlp
 
 
 ## -- avnn edges-- ##
-def avnn(comments_en,by_review = False,other_edges = True,verbose_text = False,only_otherNouns = False, only_opiAV = True, nncompound = True, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,facility=False,faciNN = False):
+def avnn(comments_en,by_review = False,other_edges = True,verbose_text = False,only_otherNouns = False, only_opiAV = True, nncompound = True, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,facility=False,faciNN = False, emojis = True,check_spell = True):
     """
     include_otherEdge: greedy edges of the unmatched adj, verb, noun 
     only_otherNouns: does not have adjverb in other2N_edges other than av2n, the other2N_edeges are greedy to mach the rest adj, verb, noun instead of considering match pattern
@@ -32,6 +32,7 @@ def avnn(comments_en,by_review = False,other_edges = True,verbose_text = False,o
     new_node_nouns= []
     new_node_verbs= []
     new_node_adjs= []
+    emojis1 = []
 
     """    by_review = False # by review or by sentence in review
         #opinion_verbs = False
@@ -54,10 +55,12 @@ def avnn(comments_en,by_review = False,other_edges = True,verbose_text = False,o
             line1 = line1.replace("."," . ") # in case: it is great.the food become a word of great.the
             line1 = line1.replace("!"," . ") # in case: it is great.the food become a word of great.the
             line1 = line1.replace("?"," . ") # ?,!, . for the sentence dependency 
+            #line1 = line1.replace("’","'")
+            line1 = re.sub(u"(\u2018|\u2019)", "'", line1)
             line1 = re.sub(' +', ' ', line1).strip() #remove extra space whitespace 
-            print('line1:', line1)
+            print('line:', line1)
             if by_review:
-                all_adjV2N_edges0, allNNedges0, all_new_nodes0, all_old_nodes0,new_node_nouns0,new_node_verbs0,new_node_adjs0 = text2edges(line1,verbose= False, verbose_text = verbose_text,include_otherEdge = other_edges,only_otherNouns =only_otherNouns,only_opiAV = only_opiAV,nncompound= nncompound, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,facility=facility,faciNN=faciNN)
+                all_adjV2N_edges0, allNNedges0, all_new_nodes0, all_old_nodes0,new_node_nouns0,new_node_verbs0,new_node_adjs0,emojis0 = text2edges(line1,verbose= False, verbose_text = verbose_text,include_otherEdge = other_edges,only_otherNouns =only_otherNouns,only_opiAV = only_opiAV,nncompound= nncompound, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,facility=facility,faciNN=faciNN,emojis = emojis,check_spell = check_spell)
                 #all_adjV2N_edges, allNNedges, all_adjV2N_edges_drop, all_new_nodes, all_old_nodes,new_node_nouns,new_node_verbs,new_node_adjs
                 allNNedges.extend(allNNedges0)
                 all_adjV2N_edges.extend(all_adjV2N_edges0)
@@ -66,12 +69,13 @@ def avnn(comments_en,by_review = False,other_edges = True,verbose_text = False,o
                 new_node_nouns.extend(new_node_nouns0)
                 new_node_verbs.extend(new_node_verbs0)
                 new_node_adjs.extend(new_node_adjs0)
+                emojis1.extend(emojis0)
             else:
                 for ib,sent in enumerate(nlp(line1).sents):   # dependency parse https://spacy.io/usage/linguistic-features#sbd sentence
                     #print(sent)
                     if len(sent.text.split())>2: # minimal 2 words
                         print('sentence' + str(ib),sent.text)
-                        all_adjV2N_edges0, allNNedges0, all_new_nodes0, all_old_nodes0,new_node_nouns0,new_node_verbs0,new_node_adjs0 = text2edges(sent.text,verbose_text = verbose_text,verbose = False,include_otherEdge = other_edges,only_otherNouns =only_otherNouns,only_opiAV = only_opiAV,nncompound= nncompound, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,facility=facility,faciNN=faciNN)
+                        all_adjV2N_edges0, allNNedges0, all_new_nodes0, all_old_nodes0,new_node_nouns0,new_node_verbs0,new_node_adjs0,emojis0 = text2edges(sent.text,verbose_text = verbose_text,verbose = False,include_otherEdge = other_edges,only_otherNouns =only_otherNouns,only_opiAV = only_opiAV,nncompound= nncompound, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,facility=facility,faciNN=faciNN,emojis = emojis,check_spell = check_spell)
                         
                         allNNedges.extend(allNNedges0)
                         all_adjV2N_edges.extend(all_adjV2N_edges0)
@@ -80,11 +84,12 @@ def avnn(comments_en,by_review = False,other_edges = True,verbose_text = False,o
                         new_node_nouns.extend(new_node_nouns0)
                         new_node_verbs.extend(new_node_verbs0)
                         new_node_adjs.extend(new_node_adjs0)
+                        emojis1.extend(emojis0)
         except:
             print('---sth wrong ---')
         
     print('processing time:', time.time()-time_start)
-    return all_adjV2N_edges,allNNedges,all_new_nodes,all_old_nodes,new_node_nouns,new_node_verbs,new_node_adjs
+    return all_adjV2N_edges,allNNedges,all_new_nodes,all_old_nodes,new_node_nouns,new_node_verbs,new_node_adjs,emojis1
 
 
 ## -- avn network -- ## 
@@ -474,4 +479,7 @@ def gray_unit(nnColor_df,Gdc,all_edges,comLen = False,plot_graph = False, save_f
       grayEdges.append(set(gray_edges))
       grayNodes.append(set(grayNodeDs))
     colorGrayDF = pd.DataFrame({'commus': commus,'colorEdges':colorEdges,'colorNodes':colorNodes,'grayEdges':grayEdges,'grayNodes':grayNodes})
-    return colorGrayDF
\ No newline at end of file
+    return colorGrayDF
+  
+  
+comments_en =["Once again a memorable visit to Arctic Light. Hearty staff, tasty breakfast (special mention of crispy waffles and rice porridge!), Clean and well-equipped room. Good bed. High quality and tastefully decorated. ❤️ We recommend and book your next stay at the Arctic Light Hotel. 😊"]
