@@ -54,14 +54,14 @@ def negADJ(neg_words,adjDEL):
 
 
 
-def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = False, only_otherNouns = False,only_opiAV = True, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,nncompound = False,facility = False,faciNN = False):
+def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = False, only_otherNouns = False,only_opiAV = True, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,nncompound = False,facility = False,faciNN = False, emojis = True, check_spell = True):
   """
   include_otherEdge: greedy edges of the unmatched adj, verb, noun 
   only_otherNouns: does not have adjverb in other2N_edges other than av2n, the other2N_edeges are greedy to mach the rest adj, verb, noun instead of considering match pattern
   nounDEL : nouns to be removed 
   adjDEL : adjective to be removed 
   facility: additional noun for the missing in the include_otherEdge class, e.g. I recommend! So pretty! 
-  faciNN: add facility noun to NN edges, otherwise facility only add to AV2N in the otherEdges other than facilty-N in the matched AV2N to form greedy NN 
+  faciNN: if True add facility noun to all NN edges, otherwise facility only add to AV2N in the otherEdges other than facilty-N in the matched AV2N to form greedy NN 
   """
   non_opi_adjs = negADJ(neg_words,adjDEL)
   
@@ -71,10 +71,19 @@ def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = Fal
   #from autocorrect import Speller
   # text2 = re.sub(r'\b' + token.text + r'\b'," ", text2)
   #line1 = re.sub(' +', ' ', line1).strip() #remove extra space whitespace 
-
+  if emojis:
+    text, emojis1 = emo(text)
+  else:
+    text = text
+    emojis1 =[]
+  
   ## --- check spelling ---##
-  spell = Speller('en')
-  text = spell(text) # restaraunt - restaurant
+  if check_spell:
+    spell = Speller('en')
+    text = spell(text) # restaraunt - restaurant
+  else:
+    text = text
+    
   text = text.replace(r"/"," ")
   text1 = text.replace("\\"," ")
   text1 = re.sub(' +', ' ', text1).strip() #remove extra space whitespace 
@@ -88,8 +97,8 @@ def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = Fal
     if token.pos_ == "NUM":
       text1 = re.sub(r'\b' + token.text + r'\b',"  pengy  ", text1)  # space in case make new compund 
   for td in nounDEL:
-    text1 = text1.replace(td," , ")
-    text1 = text1.replace(td.capitalize()," , ")
+    text1 =  re.sub(r'\b' + td + r'\b',"  ,  ", text1) 
+    text1 =  re.sub(r'\b' + td.capitalize() + r'\b'," ,  ", text1) 
   if verbose_text:
     print('text1 clean:', text1)
 
@@ -360,19 +369,24 @@ def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = Fal
   noadjNV= ""
   if len(nodes)>0:
     for x in nodes:
-      text6 = text6.replace(x,"")
+      #text6 = text6.replace(x,"")
+      text6 = re.sub(r'\b' + x + r'\b'," ", text6)
       noadjNV = text6
       #print('noadjNV',noadjNV)
   else:
     noadjNV = text6
 
+
+
   print('noadjNV',noadjNV)
+  
+  
   noadjV = []
   noN =[]
   for token in nlp(noadjNV):
-    if token.pos_ in ['ADJ','VERB']:
+    if token.pos_ in ['ADJ','VERB'] and len(token.text)>5: # and len(token.text)>5 added on 02-10.2022 , in case some emoji or short words 2vvv 
         noadjV.append(token.text)
-    elif token.pos_ == 'NOUN':
+    elif token.pos_ == 'NOUN' and len(token.text)>5:
         noN.append(token.text)
   noadjNV2 = noadjV + noN 
   noadjNV3 = " ".join(noadjNV2)
@@ -451,7 +465,7 @@ def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = Fal
         new_node_verbs.append(new_node_verb)
   all_old_nodes = old_node_adjs+old_node_nouns+old_node_verbs
   all_new_nodes = new_node_adjs+new_node_nouns+new_node_verbs
-  return all_adjV2N_edges, allNNedges, all_new_nodes, all_old_nodes,new_node_nouns,new_node_verbs,new_node_adjs
+  return all_adjV2N_edges, allNNedges, all_new_nodes, all_old_nodes,new_node_nouns,new_node_verbs,new_node_adjs,emojis1
 
 
 
@@ -474,17 +488,30 @@ def targList(mylist):
 
 #from autocorrect import Speller
 #from collections import defaultdict
-def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = False, only_otherNouns = False,opi_verbs = opi_verbs ,neg_words =neg_words,adjDEL = adjDEL,nounDEL = nounDEL,only_opiAV = True,nncompound = False):
+def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = False, only_otherNouns = False,opi_verbs = opi_verbs ,neg_words =neg_words,adjDEL = adjDEL,nounDEL = nounDEL,only_opiAV = True,nncompound = True, emojis = True,check_spell = True):
   non_opi_adjs = negADJ(neg_words,adjDEL)
   # 1. check spelling 
 
   #from autocorrect import Speller
   # text2 = re.sub(r'\b' + token.text + r'\b'," ", text2)
   #line1 = re.sub(' +', ' ', line1).strip() #remove extra space whitespace 
+  if emojis:
+    text, emojis2 = emo(text)
+  else:
+    text = text
+    emojis2 =[]
+
 
   ## --- check spelling ---##
-  spell = Speller('en')
-  text = spell(text) # restaraunt - restaurant
+  
+    ## --- check spelling ---##
+  if check_spell:
+    spell = Speller('en')
+    text = spell(text) # restaraunt - restaurant
+  else:
+    text = text
+  
+  
   text = text.replace(r"/"," ")
   text1 = text.replace("\\"," ")
   text1 = re.sub(' +', ' ', text1).strip() #remove extra space whitespace 
@@ -498,8 +525,8 @@ def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = F
     if token.pos_ == "NUM":
       text1 = re.sub(r'\b' + token.text + r'\b',"  pengy  ", text1)  # space in case make new compund 
   for td in nounDEL:
-    text1 = text1.replace(td," , ")
-    text1 = text1.replace(td.capitalize()," , ")
+    text1 =  re.sub(r'\b' + td + r'\b',"  ,  ", text1) 
+    text1 =  re.sub(r'\b' + td.capitalize() + r'\b'," ,  ", text1) 
   if verbose_text:
     print('text1 clean:', text1)
 
@@ -772,7 +799,8 @@ def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = F
   noadjNV= ""
   if len(nodes)>0:
     for x in nodes:
-      text6 = text6.replace(x,"")
+      #text6 = text6.replace(x,"")
+      text6 = re.sub(r'\b' + x + r'\b'," ", text6)
       noadjNV = text6
       #print('noadjNV',noadjNV)
   else:
@@ -810,7 +838,7 @@ def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = F
     allNNedges = nn_edges
   
  
-  return all_adjV2N_edges, allNNedges, text4b
+  return all_adjV2N_edges, allNNedges, text4b, emojis2
 
 
 
@@ -873,13 +901,23 @@ def targetPlot(text_T, avnEdges,saveAdd =False,image_size = [10,2], font_size =
     edgestring = "".join(edge)
     if '2a' in edgestring:
       color1 = 'green'
+      weight1 = 1
     elif '2v' in edgestring:
       color1 = 'red'
-    elif '2n' in edgestring:
-      color1 = 'blue'
+      weight1 = 1
+    elif '2n' in edgestring: #22.09.2022
+      edge0 = re.sub(r'[\d+]',"",edge[0])
+      edge1 = re.sub(r'[\d+]',"",edge[1])
+      if edge0 == edge1:
+        color1 = 'None'
+        weight1 =.0001
+      else:
+        color1 = 'blue'
+        weight1 =.3
     else:
       color1 = 'black'
-    G.add_edge(edge[0],edge[1],color=color1,weight=1)
+      weight1 =.3
+    G.add_edge(edge[0],edge[1],color=color1,weight=weight1)
     #G.add_edge(b,c,color='b',weight=1)
     #G.add_edge(c,d,color='g',weight=1)
 
